summaryrefslogtreecommitdiff
path: root/app/services/captcha/captcha_verification_service.rb
diff options
context:
space:
mode:
Diffstat (limited to 'app/services/captcha/captcha_verification_service.rb')
-rw-r--r--app/services/captcha/captcha_verification_service.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/app/services/captcha/captcha_verification_service.rb b/app/services/captcha/captcha_verification_service.rb
index 3ed8ea12f3a..b7b699f7108 100644
--- a/app/services/captcha/captcha_verification_service.rb
+++ b/app/services/captcha/captcha_verification_service.rb
@@ -5,7 +5,7 @@ module Captcha
# Encapsulates logic of checking captchas.
#
class CaptchaVerificationService
- include Recaptcha::Verify
+ include Recaptcha::Adapters::ControllerMethods
# Currently the only value that is used out of the request by the reCAPTCHA library
# is 'remote_ip'. Therefore, we just create a struct to avoid passing the full request
@@ -45,7 +45,7 @@ module Captcha
attr_reader :spam_params
# The recaptcha library's Recaptcha::Verify#verify_recaptcha method requires that
# 'request' be a readable attribute - it doesn't support passing it as an options argument.
attr_reader :request
end
@@ -45,7 +45,7 @@ module Captcha
attr_reader :spam_params
- # The recaptcha library's Recaptcha::Verify#verify_recaptcha method requires that
+ # The recaptcha library's Recaptcha::Adapters::ControllerMethods#verify_recaptcha method requires that
# 'request' be a readable attribute - it doesn't support passing it as an options argument.
attr_reader :request